@@ -37,7 +37,7 @@ class Client:
 
     def get_attribute(self, entry, show, attribute):
 
-        entry = entry.replace(' ', r'\ ')
+        entry = '"' + entry.replace('"', '\"') + '"'
         if show:
             cmd = ['show']
             if attribute == 'password':
